@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: LGPL-2.1-or-later */
-#ifndef __ALSA_TOOLS_HINAWA_FW_NODE_H__
-#define __ALSA_TOOLS_HINAWA_FW_NODE_H__
+#ifndef __ALSA_HINAWA_FW_NODE_H__
+#define __ALSA_HINAWA_FW_NODE_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -29,6 +29,10 @@ G_BEGIN_DECLS
 				   HINAWA_TYPE_FW_NODE,		\
 				   HinawaFwNodeClass))
 
+#define HINAWA_FW_NODE_ERROR	hinawa_fw_node_error_quark()
+
+GQuark hinawa_fw_node_error_quark();
+
 typedef struct _HinawaFwNode		HinawaFwNode;
 typedef struct _HinawaFwNodeClass	HinawaFwNodeClass;
 typedef struct _HinawaFwNodePrivate	HinawaFwNodePrivate;
@@ -46,7 +50,7 @@ struct _HinawaFwNodeClass {
 	 * HinawaFwNodeClass::bus_update:
 	 * @self: A #HinawaFwNode.
 	 *
-	 * When IEEE 1394 bus is updated, the ::bus-update handler is called.
+	 * When IEEE 1394 bus is updated, the #HinawaFwNodeClass::bus-update handler is called.
 	 * The handlers can read current generation in the bus via 'generation'
 	 * property.
 	 *
@@ -59,7 +63,7 @@ struct _HinawaFwNodeClass {
 	 * @self: A #HinawaFwNode
 	 *
 	 * When phicical FireWire devices are disconnected from IEEE 1394 bus,
-	 * the ::disconnected handler is called.
+	 * the #HinawaFwNodeClass::disconnected handler is called.
 	 *
 	 * Since: 1.4.
 	 */
