@@ -24,6 +24,8 @@
  *
  * Return the GQuark for error domain of GError which has code in #HinawaFwRespError.
  *
+ * Since: 2.2
+ *
  * Returns: A #GQuark.
  */
 G_DEFINE_QUARK(hinawa-fw-resp-error-quark, hinawa_fw_resp_error)
@@ -43,6 +45,7 @@ static const char *const err_msgs[] = {
 struct _HinawaFwRespPrivate {
 	HinawaFwNode *node;
 
+	guint64 offset;
 	guint width;
 	guint64 addr_handle;
 
@@ -56,6 +59,8 @@ G_DEFINE_TYPE_WITH_PRIVATE(HinawaFwResp, hinawa_fw_resp, G_TYPE_OBJECT)
 // This object has one property.
 enum fw_resp_prop_type {
 	FW_RESP_PROP_TYPE_IS_RESERVED = 1,
+	FW_RESP_PROP_TYPE_OFFSET,
+	FW_RESP_PROP_TYPE_WIDTH,
 	FW_RESP_PROP_TYPE_COUNT,
 };
 static GParamSpec *fw_resp_props[FW_RESP_PROP_TYPE_COUNT] = { NULL, };
@@ -78,6 +83,12 @@ static void fw_resp_get_property(GObject *obj, guint id, GValue *val,
 	case FW_RESP_PROP_TYPE_IS_RESERVED:
 		g_value_set_boolean(val, priv->node != NULL);
 		break;
+	case FW_RESP_PROP_TYPE_OFFSET:
+		g_value_set_uint64(val, priv->offset);
+		break;
+	case FW_RESP_PROP_TYPE_WIDTH:
+		g_value_set_uint(val, priv->width);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, id, spec);
 		break;
@@ -100,6 +111,11 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	gobject_class->get_property = fw_resp_get_property;
 	gobject_class->finalize = fw_resp_finalize;
 
+	/**
+	 * HinawaFwResp:is-reserved:
+	 *
+	 * Since: 2.0
+	 */
 	fw_resp_props[FW_RESP_PROP_TYPE_IS_RESERVED] =
 		g_param_spec_boolean("is-reserved", "is-reserved",
 				     "Whether a range of address is reserved "
@@ -107,6 +123,30 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 				     FALSE,
 				     G_PARAM_READABLE);
 
+	/**
+	 * HinawaFwResp:offset:
+	 *
+	 * Since: 2.3
+	 */
+	fw_resp_props[FW_RESP_PROP_TYPE_OFFSET] =
+		g_param_spec_uint64("offset", "offset",
+				    "The start offset of reserved address range.",
+				    0, G_MAXUINT64,
+				    0,
+				    G_PARAM_READABLE);
+
+	/**
+	 * HinawaFwResp:width:
+	 *
+	 * Since: 2.3
+	 */
+	fw_resp_props[FW_RESP_PROP_TYPE_WIDTH] =
+		g_param_spec_uint("width", "width",
+				  "The width of reserved address range.",
+				  0, G_MAXUINT,
+				  0,
+				  G_PARAM_READABLE);
+
 	g_object_class_install_properties(gobject_class,
 					  FW_RESP_PROP_TYPE_COUNT,
 					  fw_resp_props);
@@ -126,6 +166,7 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	 * Returns: One of #HinawaRcode enumerators corresponding to rcodes defined in IEEE 1394
 	 * specification.
 	 *
+	 * Since: 0.3
 	 * Deprecated: 2.2: Use #HinawaFwResp::requested2, instead.
 	 */
 	fw_resp_sigs[FW_RESP_SIG_TYPE_REQ] =
@@ -157,6 +198,7 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
 	 *
 	 * Returns: One of #HinawaRcode enumerators corresponding to rcodes defined in IEEE 1394
 	 *	    specification.
+	 * Since: 2.2
 	 */
 	fw_resp_sigs[FW_RESP_SIG_TYPE_REQ2] =
 		g_signal_new("requested2",
@@ -189,21 +231,24 @@ HinawaFwResp *hinawa_fw_resp_new(void)
 }
 
 /**
- * hinawa_fw_resp_reserve:
+ * hinawa_fw_resp_reserve_within_region:
  * @self: A #HinawaFwResp.
  * @node: A #HinawaFwNode.
- * @addr: A start address to listen to in host controller.
- * @width: The byte width of address to listen to host controller.
+ * @region_start:  Start offset of address region in which range of address is looked up.
+ * @region_end:  End offset of address region in which range of address is looked up.
+ * @width: The width for range of address to be looked up.
  * @exception: A #GError. Error can be generated with two domain of #hinawa_fw_node_error_quark()
  *	       and #hinawa_fw_resp_error_quark().
  *
- * Start to listen to a range of address in host controller which connects to
- * the node.
+ * Start to listen to range of address equals to #width in local node (e.g. 1394 OHCI host
+ * controller), which is used to communicate to the node given as parameter. The range of address
+ * is looked up in region between #region_start and #region_end.
  *
- * Since: 1.4.
+ * Since: 2.3.
  */
-void hinawa_fw_resp_reserve(HinawaFwResp *self, HinawaFwNode*node,
-			    guint64 addr, guint width, GError **exception)
+void hinawa_fw_resp_reserve_within_region(HinawaFwResp *self, HinawaFwNode *node,
+					  guint64 region_start, guint64 region_end, guint width,
+					  GError **exception)
 {
 	HinawaFwRespPrivate *priv;
 	struct fw_cdev_allocate allocate = {0};
@@ -219,10 +264,10 @@ void hinawa_fw_resp_reserve(HinawaFwResp *self, HinawaFwNode*node,
 		return;
 	}
 
-	allocate.offset = addr;
+	allocate.offset = region_start;
 	allocate.closure = (guint64)self;
 	allocate.length = width;
-	allocate.region_end = addr + width;
+	allocate.region_end = region_end;
 
 	err = hinawa_fw_node_ioctl(node, FW_CDEV_IOC_ALLOCATE, &allocate, exception);
 	if (*exception != NULL)
@@ -241,10 +286,32 @@ void hinawa_fw_resp_reserve(HinawaFwResp *self, HinawaFwNode*node,
 
 	priv->resp_frame = g_malloc0(allocate.length);
 
+	priv->offset = allocate.offset;
 	priv->width = allocate.length;
 	priv->addr_handle = allocate.handle;
 }
 
+/**
+ * hinawa_fw_resp_reserve:
+ * @self: A #HinawaFwResp.
+ * @node: A #HinawaFwNode.
+ * @addr: A start address to listen to in host controller.
+ * @width: The byte width of address to listen to host controller.
+ * @exception: A #GError. Error can be generated with two domain of #hinawa_fw_node_error_quark()
+ *	       and #hinawa_fw_resp_error_quark().
+ *
+ * Start to listen to a range of address in host controller which connects to the node. The function
+ * is a variant of #hinawa_fw_resp_reserve_within_region() so that the exact range of address should
+ * be reserved as given.
+ *
+ * Since: 1.4.
+ */
+void hinawa_fw_resp_reserve(HinawaFwResp *self, HinawaFwNode *node,
+			    guint64 addr, guint width, GError **exception)
+{
+	hinawa_fw_resp_reserve_within_region(self, node, addr, addr + width, width, exception);
+}
+
 /**
  * hinawa_fw_resp_release:
  * @self: A HinawaFwResp.
@@ -280,6 +347,9 @@ void hinawa_fw_resp_release(HinawaFwResp *self)
 		g_free(priv->resp_frame);
 	priv->resp_frame = NULL;
 	priv->resp_length = 0;
+
+	priv->offset = 0;
+	priv->width = 0;
 }
 
 /**
@@ -291,6 +361,7 @@ void hinawa_fw_resp_release(HinawaFwResp *self)
  *
  * Retrieve byte frame to be requested.
  *
+ * Since: 2.0
  * Deprecated: 2.2: handler for #HinawaFwResp::requested2 signal can receive the frame in its
  *		    argument.
  */
@@ -319,6 +390,8 @@ void hinawa_fw_resp_get_req_frame(HinawaFwResp *self, const guint8 **frame,
  * @length: The length of bytes for the frame.
  *
  * Register byte frame as response.
+ *
+ * Since: 2.0
  */
 void hinawa_fw_resp_set_resp_frame(HinawaFwResp *self, guint8 *frame,
 				   gsize length)
