@@ -28,6 +28,8 @@
  *
  * Return the GQuark for error domain of GError which has code in #HinawaSndUnitError.
  *
+ * Since: 2.1
+ *
  * Returns: A #GQuark.
  */
 G_DEFINE_QUARK(hinawa-snd-unit-error-quark, hinawa_snd_unit_error)
@@ -136,28 +138,58 @@ static void hinawa_snd_unit_class_init(HinawaSndUnitClass *klass)
 	gobject_class->get_property = snd_unit_get_property;
 	gobject_class->finalize = snd_unit_finalize;
 
+	/**
+	 * HinawaSndUnit:type:
+	 *
+	 * Since: 1.0
+	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_FW_TYPE] =
 		g_param_spec_enum("type", "type",
 				  "The value of HinawaSndUnitType enumerators",
 				  HINAWA_TYPE_SND_UNIT_TYPE,
 				  HINAWA_SND_UNIT_TYPE_DICE,
 				  G_PARAM_READABLE);
+
+	/**
+	 * HinawaSndUnit:card:
+	 *
+	 * Since: 2.0
+	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_CARD_ID] =
 		g_param_spec_uint("card", "card",
-				  "The numerical ID for ALSA sound card",
+				  "The numeric ID for ALSA sound card",
 				  0, G_MAXUINT,
 				  0,
 				  G_PARAM_READABLE);
+
+	/**
+	 * HinawaSndUnit:device:
+	 *
+	 *
+	 * Since: 0.3
+	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_DEVICE] =
 		g_param_spec_string("device", "device",
 				    "A name of special file as FireWire unit.",
 				    NULL,
 				    G_PARAM_READABLE);
+
+	/**
+	 * HinawaSndUnit:streaming:
+	 *
+	 * Since: 0.4
+	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_STREAMING] =
 		g_param_spec_boolean("streaming", "streaming",
 				     "Whether this device is streaming or not",
 				     FALSE,
 				     G_PARAM_READABLE);
+
+	/**
+	 * HinawaSndUnit:guid:
+	 *
+	 * Since: 0.4
+	 */
 	snd_unit_props[SND_UNIT_PROP_TYPE_GUID] =
 		g_param_spec_uint64("guid", "guid",
 				    "Global unique ID for this firewire unit.",
@@ -175,6 +207,8 @@ static void hinawa_snd_unit_class_init(HinawaSndUnitClass *klass)
 	 *
 	 * When ALSA kernel-streaming status is changed, this #HinawaSndUnit::lock-status
 	 * signal is generated.
+	 *
+	 * Since: 0.3
 	 */
 	snd_unit_sigs[SND_UNIT_SIG_TYPE_LOCK_STATUS] =
 		g_signal_new("lock-status",
@@ -193,6 +227,8 @@ static void hinawa_snd_unit_class_init(HinawaSndUnitClass *klass)
 	 * or hot unplugging, this signal is emit. The owner of this object
 	 * should call g_object_free() as quickly as possible to release ALSA
 	 * hwdep character device.
+	 *
+	 * Since: 2.0
 	 */
 	snd_unit_sigs[SND_UNIT_SIG_TYPE_DISCONNECTED] =
 		g_signal_new("disconnected",
@@ -233,6 +269,8 @@ HinawaSndUnit *hinawa_snd_unit_new(void)
  *	       #hinawa_fw_node_error_quark(), and #hinawa_snd_unit_error_quark().
  *
  * Open ALSA hwdep character device and check it for FireWire sound devices.
+ *
+ * Since: 0.4
  */
 void hinawa_snd_unit_open(HinawaSndUnit *self, gchar *path, GError **exception)
 {
@@ -275,36 +313,26 @@ void hinawa_snd_unit_open(HinawaSndUnit *self, gchar *path, GError **exception)
 		goto end;
 	}
 
-#if HAVE_SND_DICE
 	if (HINAWA_IS_SND_DICE(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_DICE) {
 		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
-#endif
-#if HAVE_SND_EFW
 	if (HINAWA_IS_SND_EFW(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_FIREWORKS) {
 		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
-#endif
-#if HAVE_SND_DG00X
 	if (HINAWA_IS_SND_DG00X(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_DIGI00X) {
 		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
-#endif
-#if HAVE_SND_MOTU
 	if (HINAWA_IS_SND_MOTU(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_MOTU) {
 		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
-#endif
-#if HAVE_SND_TSCM
 	if (HINAWA_IS_SND_TSCM(self) && priv->info.type != SNDRV_FIREWIRE_TYPE_TASCAM) {
 		generate_local_error(exception, HINAWA_SND_UNIT_ERROR_WRONG_CLASS);
 		goto end;
 	}
-#endif
 	snprintf(fw_cdev, sizeof(fw_cdev), "/dev/%s", priv->info.device_name);
 	hinawa_fw_node_open(priv->node, fw_cdev, exception);
 end:
@@ -341,6 +369,8 @@ void hinawa_snd_unit_get_node(HinawaSndUnit *self, HinawaFwNode **node)
  * @exception: A #GError. Error can be generated with domain of #hinawa_snd_unit_error_quark().
  *
  * Disallow ALSA to start kernel-streaming.
+ *
+ * Since: 0.3
  */
 void hinawa_snd_unit_lock(HinawaSndUnit *self, GError **exception)
 {
@@ -371,6 +401,8 @@ void hinawa_snd_unit_lock(HinawaSndUnit *self, GError **exception)
  * @exception: A #GError. Error can be generated with domain of #hinawa_snd_unit_error_quark().
  *
  * Allow ALSA to start kernel-streaming.
+ *
+ * Since: 0.3
  */
 void hinawa_snd_unit_unlock(HinawaSndUnit *self, GError **exception)
 {
@@ -443,11 +475,18 @@ void hinawa_snd_unit_ioctl(HinawaSndUnit *self, unsigned long request,
 			const char *arg;
 
 			switch (request) {
-#if HAVE_SND_TSCM
 			case SNDRV_FIREWIRE_IOCTL_TASCAM_STATE:
 				arg = "SNDRV_FIREWIRE_IOCTL_TASCAM_STATE";
 				break;
-#endif
+			case SNDRV_FIREWIRE_IOCTL_MOTU_REGISTER_DSP_METER:
+				arg = "SNDRV_FIREWIRE_IOCTL_MOTU_REGISTER_DSP_METER";
+				break;
+			case SNDRV_FIREWIRE_IOCTL_MOTU_COMMAND_DSP_METER:
+				arg = "SNDRV_FIREWIRE_IOCTL_MOTU_COMMAND_DSP_METER";
+				break;
+			case SNDRV_FIREWIRE_IOCTL_MOTU_REGISTER_DSP_PARAMETER:
+				arg = "SNDRV_FIREWIRE_IOCTL_MOTU_REGISTER_DSP_PARAMETER";
+				break;
 			default:
 				arg = "Unknown";
 				break;
@@ -511,36 +550,31 @@ static gboolean dispatch_src(GSource *gsrc, GSourceFunc cb, gpointer user_data)
 
 	if (common->type == SNDRV_FIREWIRE_EVENT_LOCK_STATUS)
 		handle_lock_event(unit, src->buf, len);
-#if HAVE_SND_DICE
 	else if (HINAWA_IS_SND_DICE(unit) &&
 		 common->type == SNDRV_FIREWIRE_EVENT_DICE_NOTIFICATION)
 		hinawa_snd_dice_handle_notification(HINAWA_SND_DICE(unit),
 						    src->buf, len);
-#endif
-#if HAVE_SND_EFW
 	else if (HINAWA_IS_SND_EFW(unit) &&
 		 common->type == SNDRV_FIREWIRE_EVENT_EFW_RESPONSE)
 		hinawa_snd_efw_handle_response(HINAWA_SND_EFW(unit),
 					       src->buf, len);
-#endif
-#if HAVE_SND_DG00X
 	else if (HINAWA_IS_SND_DG00X(unit) &&
 		 common->type == SNDRV_FIREWIRE_EVENT_DIGI00X_MESSAGE)
 		hinawa_snd_dg00x_handle_msg(HINAWA_SND_DG00X(unit),
 					    src->buf, len);
-#endif
-#if HAVE_SND_MOTU
-	else if (HINAWA_IS_SND_MOTU(unit) &&
-		 common->type == SNDRV_FIREWIRE_EVENT_MOTU_NOTIFICATION)
-		hinawa_snd_motu_handle_notification(HINAWA_SND_MOTU(unit),
-						    src->buf, len);
-#endif
-#if HAVE_SND_TSCM
+	else if (HINAWA_IS_SND_MOTU(unit)) {
+		HinawaSndMotu *motu = HINAWA_SND_MOTU(unit);
+
+		if (common->type == SNDRV_FIREWIRE_EVENT_MOTU_NOTIFICATION) {
+			hinawa_snd_motu_handle_notification(motu, src->buf, len);
+		} else if (common->type == SNDRV_FIREWIRE_EVENT_MOTU_REGISTER_DSP_CHANGE) {
+			hinawa_snd_motu_handle_register_dsp_change(motu, src->buf, len);
+		}
+	}
 	else if (HINAWA_IS_SND_TSCM(unit) &&
 		 common->type == SNDRV_FIREWIRE_EVENT_TASCAM_CONTROL)
 		hinawa_snd_tscm_handle_control(HINAWA_SND_TSCM(unit),
 						    src->buf, len);
-#endif
 end:
 	/* Just be sure to continue to process this source. */
 	return G_SOURCE_CONTINUE;
